#ifndef LIBKYAPPINSTSEC_H
#define LIBKYAPPINSTSEC_H

typedef enum _KDK_PKG_BWLIST_TYPE 
{
    KDK_PKG_BWLIST_TYPE_NORMAL = 0,         // 未开启安装控制黑白名单
    KDK_PKG_BWLIST_TYPE_WHITELIST,          // 安装控制白名单
    KDK_PKG_BWLIST_TYPE_BLACKLIST,          // 安装控制黑名单
} KDK_PKG_BWLIST_TYPE;

#ifdef __cplusplus
extern "C" {
#endif

/**
 * @brief 添加一个包到安装控制黑白名单中
 * @param type[in] 类型，参考KDK_PKG_BWLIST_TYPE
 * @param pkgname[in] 包名
 * @return int 0:成功，-1:出错, 1：软件包已经在列表
 */
int kdk_pkg_bwlist_add(int type, const char *pkgname);

/**
 * @brief 删除一个包从安装控制黑白名单中
 * @param type[in] 类型，参考KDK_PKG_BWLIST_TYPE
 * @param pkgname[in] 包名
 * @return int 0:成功，-1:出错，1:不存在
 */
int kdk_pkg_bwlist_del(int type, const char *pkgname);

/**
 * @brief 获取安装控制黑白名单开关标识
 * @return int 返回值参考KDK_PKG_BWLIST_TYPE, -1: 失败
 */
int kdk_pkg_bwlist_get_mode(void);

/**
 * @brief 设置安装控制黑白名单开关标识，黑名单开启时，黑名单中的包不能安装；白名单开启时，只有白名单中的包可以安装
 * @param type[in] 类型，参考KDK_PKG_BWLIST_TYPE
 * @return int 0:成功，-1:失败
 */
int kdk_pkg_bwlist_set_model(int type);

#ifdef __cplusplus
}
#endif

#endif // LIBKYAPPINSTSEC_H
